@@ -6,9 +6,11 @@ use clap::{crate_authors, crate_version, load_yaml, App, AppSettings};
 use url::Url;
 
 use crate::beacon::Beacon;
+use crate::framework::Framework;
 use crate::spec::Spec;
 
 mod beacon;
+mod framework;
 mod interface;
 mod spec;
 mod utils;
@@ -35,11 +37,17 @@ fn run() -> Result<(), Box<dyn Error>> {
 	}
 	pretty_env_logger::init();
 
+	// Load framework
+	let framework_location = matches.value_of_t("framework")?;
+	log::debug!("Loading framework from: {}", &framework_location);
+	let framework = Framework::load(&framework_location).expect("Loading framework failed");
+	log::debug!("Framework loaded");
+
 	// Load spec
 	let spec_location = matches.value_of_t("spec")?;
 	log::debug!("Loading spec from: {}", spec_location);
-	let spec = Spec::load(&spec_location).expect("Load spec failed");
-	let n_entitites = spec.validate()?;
+	let spec = Spec::load(&spec_location).expect("Loading spec failed");
+	let n_entitites = spec.validate(&framework)?;
 	log::info!("Valid spec (number of entities: {})", n_entitites);
 
 	// Validate beacons
@@ -48,7 +56,7 @@ fn run() -> Result<(), Box<dyn Error>> {
 		let mut output = Vec::new();
 		for beacon_url in matches.values_of_t::<Url>("URLS")? {
 			log::info!("Validating implementation on {}", beacon_url);
-			match Beacon::new(spec.clone(), beacon_url) {
+			match Beacon::new(spec.clone(), framework.clone(), beacon_url) {
 				Ok(beacon) => match beacon.validate() {
 					Ok(beacon_output) => output.push(beacon_output),
 					Err(e) => {
